@@ -42,6 +42,9 @@ from functions_framework.exceptions import (
 )
 from google.cloud.functions.context import Context
 from functions_framework._of.v2.context import FunctionContext
+_FUNC_CTX = dict()
+KNATIVE_FUNC = "Knative"
+ASYNC = "OpenFuncAsync"
 
 MAX_CONTENT_LENGTH = 10 * 1024 * 1024
 
@@ -410,7 +413,23 @@ class LazyWSGIApp:
 
     def __call__(self, *args, **kwargs):
         if not self.app:
-            self.app = create_app(self.target, self.source, self.signature_type)
+            ff = os.getenv("FUNC_CONTEXT", "")
+            if  ff == "":
+                print("start http app")
+                self.app = create_app(self.target, self.source, self.signature_type)
+            else:
+                _ctx = parse_function_context()
+                port = _ctx.port
+                if _ctx.runtime == KNATIVE_FUNC:
+                    print("start http app")
+                    self.app = create_app(self.target, self.source, self.signature_type)
+                elif _ctx.runtime == ASYNC:
+                    signature_type = "of"
+                    print(datetime.now())
+                    print("start dapr app")
+                    self.app = create_dapr_app(self.target, self.source, self.signature_type, _ctx)
+                    print("start dapr service")
+                    print(datetime.now())
         return self.app(*args, **kwargs)
 
 
